@@ -1,5 +1,7 @@
 """
-Main interface for emr-containers service literal definitions.
+Type annotations for emr-containers service literal definitions.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/literals.html)
 
 Usage::
 
